==============
 Introduction
==============

These pages describe a Git_ and GitHub_ workflow for the `ODL`_ project.

This is not a comprehensive Git reference, it is just a workflow for our own project, tailored
to the GitHub hosting service. You may well find better or quicker ways of getting stuff done with
Git, but these instructions should get you started.

For general resources for learning Git, see :ref:`git-resources`.

.. include:: links.inc
